@@ -617,20 +617,22 @@ main (int argc, char *const *argv)
   errorCount += testStopRace (0);
   errorCount += testExternalGet ();
   errorCount += testEmptyGet (0);
-#ifndef WINDOWS
-  errorCount += testInternalGet (MHD_USE_POLL);
-  errorCount += testMultithreadedGet (MHD_USE_POLL);
-  errorCount += testMultithreadedPoolGet (MHD_USE_POLL);
-  errorCount += testUnknownPortGet (MHD_USE_POLL);
-  errorCount += testStopRace (MHD_USE_POLL);
-  errorCount += testEmptyGet (MHD_USE_POLL);
-#endif
-#if EPOLL_SUPPORT
-  errorCount += testInternalGet (MHD_USE_EPOLL_LINUX_ONLY);
-  errorCount += testMultithreadedPoolGet (MHD_USE_EPOLL_LINUX_ONLY);
-  errorCount += testUnknownPortGet (MHD_USE_EPOLL_LINUX_ONLY);
-  errorCount += testEmptyGet (MHD_USE_EPOLL_LINUX_ONLY);
-#endif
+  if (MHD_YES == MHD_is_feature_supported(MHD_FEATURE_POLL))
+    {
+      errorCount += testInternalGet(MHD_USE_POLL);
+      errorCount += testMultithreadedGet(MHD_USE_POLL);
+      errorCount += testMultithreadedPoolGet(MHD_USE_POLL);
+      errorCount += testUnknownPortGet(MHD_USE_POLL);
+      errorCount += testStopRace(MHD_USE_POLL);
+      errorCount += testEmptyGet(MHD_USE_POLL);
+    }
+  if (MHD_YES == MHD_is_feature_supported(MHD_FEATURE_EPOLL))
+    {
+      errorCount += testInternalGet(MHD_USE_EPOLL_LINUX_ONLY);
+      errorCount += testMultithreadedPoolGet(MHD_USE_EPOLL_LINUX_ONLY);
+      errorCount += testUnknownPortGet(MHD_USE_EPOLL_LINUX_ONLY);
+      errorCount += testEmptyGet(MHD_USE_EPOLL_LINUX_ONLY);
+    }
   if (errorCount != 0)
     fprintf (stderr, "Error (code: %u)\n", errorCount);
   curl_global_cleanup ();
